## $Id: fileviewlets.py 12224 2014-12-14 09:08:16Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.ikoba.interfaces import MessageFactory as _

from waeup.ikoba.browser.fileviewlets import (
    FileDisplay, FileUpload, Image)

from waeup.ikoba.customers.interfaces import ICustomer

from waeup.ikoba.customers.documents import (
    CustomerSampleDocument, CustomerPDFDocument
    )
from waeup.ikoba.customers.browser import (
    CustomerBaseDisplayFormPage, CustomerBaseManageFormPage,
    CustomerFilesUploadPage,
    DocumentDisplayFormPage, DocumentManageFormPage, DocumentEditFormPage,
    PDFDocumentSlipPage,)

grok.templatedir('browser_templates')

# File viewlets for customer base page

class PassportDisplay(FileDisplay):
    """Passport display viewlet.
    """
    grok.order(1)
    grok.context(ICustomer)
    grok.view(CustomerBaseDisplayFormPage)
    grok.require('waeup.viewCustomer')
    grok.template('imagedisplay')
    label = _(u'Passport Picture')
    download_name = u'passport.jpg'


class PassportManageUpload(FileUpload):
    """Passport upload viewlet for officers.
    """
    grok.order(1)
    grok.context(ICustomer)
    grok.view(CustomerBaseManageFormPage)
    grok.require('waeup.manageCustomer')
    grok.template('imageupload')
    label = _(u'Passport Picture (jpg only)')
    mus = 1024 * 50
    download_name = u'passport.jpg'
    tab_redirect = '#tab2'


class PassportEditUpload(PassportManageUpload):
    """Passport upload viewlet for customers.
    """
    grok.view(CustomerFilesUploadPage)
    grok.require('waeup.uploadCustomerFile')


class Passport(Image):
    """Renders jpeg passport picture.
    """
    grok.name('passport.jpg')
    download_name = u'passport.jpg'
    grok.context(ICustomer)
    grok.require('waeup.viewCustomer')

# File viewlets for customer documents

class SampleScanManageUpload(FileUpload):
    """Scan upload viewlet for officers.
    """
    grok.order(1)
    grok.context(CustomerSampleDocument)
    grok.view(DocumentManageFormPage)
    grok.require('waeup.manageCustomer')
    label = _(u'Sample Scan')
    title = _(u'Sample Scan')
    mus = 1024 * 50
    download_name = u'sample'
    tab_redirect = '#tab2'


class SampleScanEditUpload(SampleScanManageUpload):
    """Scan upload viewlet for customer.
    """
    grok.view(DocumentEditFormPage)
    grok.require('waeup.handleCustomer')


class SampleScanDisplay(FileDisplay):
    """Scan display viewlet.
    """
    grok.order(1)
    grok.context(CustomerSampleDocument)
    grok.require('waeup.viewCustomer')
    grok.view(DocumentDisplayFormPage)
    label = _(u'Sample Scan')
    title = _(u'Sample Scan')
    download_name = u'sample'


class SampleScanImage(Image):
    """Scan document.
    """
    grok.name('sample')
    grok.context(CustomerSampleDocument)
    grok.require('waeup.viewCustomer')
    download_name = u'sample'

class SampleScanPDFSlip(SampleScanDisplay):
    grok.view(PDFDocumentSlipPage)


class PDFScanManageUpload(FileUpload):
    """Scan upload viewlet for officers.
    """
    grok.view(DocumentManageFormPage)
    grok.context(CustomerPDFDocument)
    grok.require('waeup.manageCustomer')
    label = _(u'PDF File')
    title = _(u'PDF File')
    mus = 1024 * 200
    download_name = u'sample.pdf'
    tab_redirect = '#tab2'


class PDFScanEditUpload(PDFScanManageUpload):
    """Scan upload viewlet for customer.
    """
    grok.view(DocumentEditFormPage)
    grok.require('waeup.handleCustomer')


class PDFScanDisplay(FileDisplay):
    """Scan display viewlet.
    """
    grok.order(1)
    grok.context(CustomerPDFDocument)
    grok.require('waeup.viewCustomer')
    grok.view(DocumentDisplayFormPage)
    label = _(u'PDF Scan')
    title = _(u'PDF Scan')
    download_name = u'sample.pdf'


class PDFScanImage(Image):
    """Scan document.
    """
    grok.name('sample.pdf')
    grok.context(CustomerPDFDocument)
    grok.require('waeup.viewCustomer')
    download_name = u'sample.pdf'

class PDFScanSlip(PDFScanDisplay):
    grok.view(PDFDocumentSlipPage)
